import * as monaco from 'monaco-editor';
import { EmacsExtension } from './index';
export declare const SOURCE = "extension.emacs";
export declare abstract class BaseAction {
    description: string;
    abstract run(editor: monaco.editor.IStandaloneCodeEditor, ext: EmacsExtension, repeat: number, repeatedTrigger: boolean): void;
}
declare class TriggerAction extends BaseAction {
    trigger: string;
    constructor(trigger: string);
    run(editor: monaco.editor.IStandaloneCodeEditor): void;
}
export declare class KillSelection extends BaseAction {
    run(editor: monaco.editor.IStandaloneCodeEditor, ext: EmacsExtension, repeat: number, repeatedTrigger: boolean): void;
}
export declare class KillLines extends BaseAction {
    run(editor: monaco.editor.IStandaloneCodeEditor, ext: EmacsExtension, repeat: number, repeatedTrigger: boolean): void;
}
export declare class InsertLineBelow extends BaseAction {
    run(editor: monaco.editor.IStandaloneCodeEditor, ext: EmacsExtension, repeat: number, repeatedTrigger: boolean): void;
}
export declare class InsertLineAfter extends BaseAction {
    run(editor: monaco.editor.IStandaloneCodeEditor, ext: EmacsExtension, repeat: number, repeatedTrigger: boolean): void;
}
export declare class SetMark extends BaseAction {
    run(editor: monaco.editor.IStandaloneCodeEditor, ext: EmacsExtension, repeat: number, repeatedTrigger: boolean): void;
}
declare class MoveCursorAction extends BaseAction {
    direction: string;
    unit: string;
    run(editor: monaco.editor.IStandaloneCodeEditor, ext: EmacsExtension, repeat: number, repeatedTrigger: boolean): void;
}
export declare class MoveCursorUp extends MoveCursorAction {
    direction: string;
}
export declare class MoveCursorDown extends MoveCursorAction {
    direction: string;
}
export declare class MoveCursorLeft extends MoveCursorAction {
    direction: string;
}
export declare class MoveCursorRight extends MoveCursorAction {
    direction: string;
}
export declare class MoveCursorToLineEnd extends MoveCursorAction {
    direction: string;
}
export declare class MoveCursorToLineStart extends MoveCursorAction {
    direction: string;
}
export declare class MoveCursorWordRight extends MoveCursorRight {
    unit: string;
}
export declare class MoveCursorWordLeft extends MoveCursorLeft {
    unit: string;
}
export declare class MoveCursorBottom extends MoveCursorAction {
    direction: string;
}
export declare class MoveCursorTop extends MoveCursorAction {
    direction: string;
}
export declare class KeyBoardQuit extends BaseAction {
    run(editor: monaco.editor.IStandaloneCodeEditor, ext: EmacsExtension, repeat: number, repeatedTrigger: boolean): void;
}
declare class HistoryAction extends BaseAction {
    action: string;
    run(editor: monaco.editor.IStandaloneCodeEditor, ext: EmacsExtension, repeat: number, repeatedTrigger: boolean): void;
}
export declare class UndoAction extends HistoryAction {
    action: string;
}
export declare class RedoAction extends HistoryAction {
    action: string;
}
export declare class Yank extends BaseAction {
    run(editor: monaco.editor.IStandaloneCodeEditor, ext: EmacsExtension, repeat: number, repeatedTrigger: boolean): void;
}
export declare class YankSelectionToRing extends BaseAction {
    run(editor: monaco.editor.IStandaloneCodeEditor, ext: EmacsExtension, repeat: number, repeatedTrigger: boolean): void;
}
export declare class YankRotate extends BaseAction {
    run(editor: monaco.editor.IStandaloneCodeEditor, ext: EmacsExtension, repeat: number, repeatedTrigger: boolean): void;
}
export declare class RevealEditorAction extends BaseAction {
    revealFunction: string;
    run(editor: monaco.editor.IStandaloneCodeEditor, ext: EmacsExtension, repeat: number, repeatedTrigger: boolean): void;
}
export declare class RevealToTopAction extends RevealEditorAction {
    revealFunction: string;
}
export declare class RevealToCenterAction extends RevealEditorAction {
    revealFunction: string;
}
export declare class RevealToBottomAction extends RevealEditorAction {
    revealFunction: string;
}
export declare class InsertTabs extends BaseAction {
    run(editor: monaco.editor.IStandaloneCodeEditor, ext: EmacsExtension, repeat: number, repeatedTrigger: boolean): void;
}
export declare class RotateCursorOnScreen extends BaseAction {
    run(editor: monaco.editor.IStandaloneCodeEditor, ext: EmacsExtension, repeat: number, repeatedTrigger: boolean): void;
}
export declare class GotoLine extends BaseAction {
    run(editor: monaco.editor.IStandaloneCodeEditor, ext: EmacsExtension, repeat: number, repeatedTrigger: boolean): void;
}
export declare class InvertSelection extends BaseAction {
    run(editor: monaco.editor.IStandaloneCodeEditor, ext: EmacsExtension, repeat: number, repeatedTrigger: boolean): void;
}
export declare class Search extends TriggerAction {
    constructor();
}
export declare class SearchReplace extends TriggerAction {
    constructor();
}
export declare class DeleteLines extends BaseAction {
    run(editor: monaco.editor.IStandaloneCodeEditor, ext: EmacsExtension, repeat: number, repeatedTrigger: boolean): void;
}
export {};
